autosubmit.config
=================

autosubmit.config.basicConfig
-----------------------------

.. automodule:: autosubmit.config.basicConfig
   :show-inheritance:
   :inherited-members:
   :members:

autosubmit.config.config_common
-------------------------------
.. automodule:: autosubmit.config.config_common
   :show-inheritance:
   :inherited-members:
   :members:

